@@ -4,7 +4,7 @@
 ----
 
 """
-from Fishconsole import houtai
+from Fishconsole import houtai #没有意义，就是覆写
 
 try:
     import re
@@ -1320,6 +1320,44 @@ def 任务平均分配(任务数量, 数据源: list):
         logs.安全退出("任务平均分配》数据源类型检测》请指定正确的类型")
 
 
+def 进程存活性检测(pid):
+    import psutil  # 进程检测库
+    from Fishconsole import files, logs
+    if not files.强制类型检测(pid, ["int", 'str']):
+        logs.安全退出("进程存活性检测》请指定int或str类型的数据源")
+    pid = int(pid)
+    pids = psutil.process_iter()
+    for a in pids:
+        if a.pid == pid:
+            return True
+    return False
+
+
+
+def 随机IP代理():
+    from Fishconsole import files
+    if 进程存活性检测(files.缓存(2,文件名="C:\Fishconsole\programes\Tempfiles\houtai_core.fcc",变量名="ipmadomPid")):
+        列表=files.缓存(2,文件名="C:\Fishconsole\programes\Tempfiles\ipCore.fcc",变量名='Available')
+        if files.强制类型检测(列表,['list']):
+            try:
+                if not int(len(列表))==0:
+                    import random
+                    for a in range(30):
+                        return 列表[random.randint(0,int(len(列表)-1))]
+                else:
+                    print('代理池为空')
+            except TypeError:
+                print(logs.日志('代理池不存在，这应该是因为代理池没有启动，请前往fcv.debug查看代理池是否已经启动','红色'))
+                return False
+        else:
+            print(logs.日志('代理池为空，这应该是因为代理池没有启动或刚刚启动或者网不行，请前往fcv.debug查看代理池是否已经启动', '红色'))
+            return False
+
+    else:
+        print(logs.日志('代理池主程序未启动，请前往fcv.debug查看代理池是否已经启动', '红色'))
+        return False
+
+
 # 规定调用次数
 # import time
 # from functools import wraps
